<!-- ROW START -->
<div class="row py-5">
    <div class="col-lg-12 col-md-12 mb-4 mb-xl-0 mb-lg-4">
        <x-cards.data :title="__('app.menu.projects')">
            Projects data
        </x-cards.data>
    </div>

</div>
<!-- ROW END -->
